@@ -6,6 +6,8 @@
  *
  *   Installs Drupal and checks that the given URL by sql-connect is correct.
  *   @TODO: test Postgre-SQL and Sqlite.
+ *
+ * @group commands
  */
 class SqlConnectCase extends Drush_CommandTestCase {
 
@@ -17,7 +19,6 @@ class SqlConnectCase extends Drush_CommandTestCase {
       'uri' => key($sites),
     );
 
-    // Get the connection details with sql-connect and check its structure.
     $this->drush('sql-connect', array(), $options);
     $output = $this->getOutput();
     $this->assertRegExp('/^mysql --database=[^\s]+ --host=[^\s]+ --user=[^\s]+ --password=.*$/', $output);
@@ -26,5 +27,10 @@ class SqlConnectCase extends Drush_CommandTestCase {
     $this->execute($output . ' -e "select name from users where uid = 1;"');
     $output = $this->getOutput();
     $this->assertContains('admin', $output);
+
+    // Get the connection details with sql-connect and check its structure.
+    if (strpos(UNISH_DB_URL, 'mysql') === FALSE) {
+      $this->markTestSkipped('sql-connect tests need updating for non-mysql UNISH_DB_URL.');
+    }
   }
 }
